# coding=utf-8
# Copyright 2021 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Tests for titanic data loading."""

from tensorflow_datasets.structured import titanic
import tensorflow_datasets.testing as tfds_test


class TitanicTest(tfds_test.DatasetBuilderTestCase):
  DATASET_CLASS = titanic.Titanic

  SPLITS = {'train': 5}

  DL_EXTRACT_RESULT = 'test.csv'


if __name__ == '__main__':
  tfds_test.test_main()
